@@ -9,6 +9,7 @@
 
 #include <KEduVocDocument>
 #include <KEduVocWordtype>
+#include <QRegularExpression>
 
 using namespace Practice;
 
@@ -64,11 +65,7 @@ void GenderBackendMode::prepareChoices(TestEntry *entry)
     QString noun = entry->entry()->translation(m_current->languageTo())->text();
 
     // strip the article
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    QStringList qsl = noun.split(QRegExp(QStringLiteral("\\s")), QString::SkipEmptyParts);
-#else
-    QStringList qsl = noun.split(QRegExp(QStringLiteral("\\s")), Qt::SkipEmptyParts);
-#endif
+    QStringList qsl = noun.split(QRegularExpression(QStringLiteral("\\s")), Qt::SkipEmptyParts);
     QMutableStringListIterator qsli(qsl);
     while (qsli.hasNext())
         if (m_articles.isArticle(qsli.next()))
